This project represents the implicit namespace ``sav`` in the names of
packages such as ``sav.channels``. Note that this project is not a
dependency of such packages. It exists merely to indicate that
an explicit module named ``sav`` would cause a namespace conflict with
these packages. Installing this package will add a ``sav.info`` module
that attaches a docstring to the ``sav`` namespace when imported.






